==> eiffelstudio-23.09.10.7341.tar: F_code/C4/xm195.c <==
/*
 * Code for class XM_CALLBACKS_TO_TREE_FILTER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "xm195.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {XM_CALLBACKS_TO_TREE_FILTER}.initialize */
void F270_2579 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = RTLNSMART(eif_new_type(1990, 1).id);
	F1991_19767(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) NULL;
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,1521,0xFF01,1183,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F1518_14887(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_4_) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.enable_position_table */
void F270_2583 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_5_) = (EIF_REFERENCE) arg1;
	tr1 = RTLNSMART(eif_new_type(9, 0).id);
	F10_126(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.on_start */
void F270_2585 (EIF_REFERENCE Current)
{
	GTCX
	
	
	F270_2579(Current);
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.on_start_tag */
void F270_2586 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
	RTLI(9);
	RTLR(0,loc2);
	RTLR(1,arg1);
	RTLR(2,loc3);
	RTLR(3,Current);
	RTLR(4,tr1);
	RTLR(5,loc1);
	RTLR(6,arg3);
	RTLR(7,arg2);
	RTLR(8,tr2);
	RTLIU(9);
	
	RTGC;
	RTCT0("has_resolved_namespaces", EX_CHECK);
	loc2 = arg1;
	if (EIF_TEST(loc2)) {
		RTCK0;
	} else {
		RTCF0;
	}
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	loc3 = tr1;
	if (EIF_TEST(loc3)) {
		loc1 = RTLNS(eif_new_type(1991, 0x01).id, 1991, _OBJSIZ_4_0_0_0_0_0_0_0_);
		tr1 = F270_2593(Current, loc2, arg2);
		F1992_19783(RTCW(loc1), loc3, arg3, tr1);
	} else {
		loc1 = RTLNS(eif_new_type(1991, 0x01).id, 1991, _OBJSIZ_4_0_0_0_0_0_0_0_);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tr2 = F270_2593(Current, loc2, arg2);
		F1992_19784(RTCW(loc1), tr1, arg3, tr2);
	}
	RTAR(Current, loc1);
	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) loc1;
	F270_2595(Current, loc1);
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.on_attribute */
void F270_2587 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3, EIF_REFERENCE arg4)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(9);
	RTLR(0,loc2);
	RTLR(1,arg1);
	RTLR(2,loc3);
	RTLR(3,Current);
	RTLR(4,tr1);
	RTLR(5,loc1);
	RTLR(6,arg3);
	RTLR(7,arg2);
	RTLR(8,arg4);
	RTLIU(9);
	
	RTGC;
	RTCT0("has_resolved_namespaces", EX_CHECK);
	loc2 = arg1;
	if (EIF_TEST(loc2)) {
		RTCK0;
	} else {
		RTCF0;
	}
	RTCT0("element_not_void", EX_CHECK);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	loc3 = tr1;
	if (EIF_TEST(loc3)) {
		RTCK0;
	} else {
		RTCF0;
	}
	loc1 = RTLNS(eif_new_type(1988, 0x01).id, 1988, _OBJSIZ_4_0_0_0_0_0_0_0_);
	tr1 = F270_2593(Current, loc2, arg2);
	F1989_19720(RTCW(loc1), arg3, tr1, arg4, loc3);
	F270_2595(Current, loc1);
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.on_content */
void F270_2588 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc2);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc1);
	RTLR(4,arg1);
	RTLIU(5);
	
	RTGC;
	RTCT0("not_finished", EX_CHECK);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	loc2 = tr1;
	if (EIF_TEST(loc2)) {
		RTCK0;
	} else {
		RTCF0;
	}
	loc1 = RTLNS(eif_new_type(1986, 0x01).id, 1986, _OBJSIZ_2_0_0_0_0_0_0_0_);
	F1987_19703(RTCW(loc1), loc2, arg1);
	F270_2595(Current, loc1);
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.on_end_tag */
void F270_2589 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(4);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc2);
	RTLIU(4);
	
	RTGC;
	RTCT0("open_composite_exists", EX_CHECK);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	loc1 = tr1;
	if (EIF_TEST(loc1)) {
		RTCK0;
	} else {
		RTCF0;
	}
	tb1 = '\01';
	tr1 = *(EIF_REFERENCE *)(loc1);
	loc2 = tr1;
	if (!((EIF_BOOLEAN) !(EIF_TRUE))) {
		tb2 = F1981_19678(loc2);
		tb1 = tb2;
	}
	if (tb1) {
		*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) NULL;
	} else {
		tr1 = F1981_19675(loc1);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) tr1;
	}
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.on_processing_instruction */
void F270_2590 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(6);
	RTLR(0,loc2);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc1);
	RTLR(4,arg1);
	RTLR(5,arg2);
	RTLIU(6);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	loc2 = tr1;
	if (EIF_TEST(loc2)) {
		loc1 = RTLNS(eif_new_type(1984, 0x01).id, 1984, _OBJSIZ_3_0_0_0_0_0_0_0_);
		F1985_19689(RTCW(loc1), loc2, arg1, arg2);
	} else {
		loc1 = RTLNS(eif_new_type(1984, 0x01).id, 1984, _OBJSIZ_3_0_0_0_0_0_0_0_);
		F1985_19690(RTCW(loc1), *(EIF_REFERENCE *)(Current + _REFACS_1_), arg1, arg2);
	}
	F270_2595(Current, loc1);
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.on_comment */
void F270_2591 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc2);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc1);
	RTLR(4,arg1);
	RTLIU(5);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	loc2 = tr1;
	if (EIF_TEST(loc2)) {
		loc1 = RTLNS(eif_new_type(1985, 0x01).id, 1985, _OBJSIZ_2_0_0_0_0_0_0_0_);
		F1986_19697(RTCW(loc1), loc2, arg1);
	} else {
		loc1 = RTLNS(eif_new_type(1985, 0x01).id, 1985, _OBJSIZ_2_0_0_0_0_0_0_0_);
		F1986_19698(RTCW(loc1), *(EIF_REFERENCE *)(Current + _REFACS_1_), arg1);
	}
	F270_2595(Current, loc1);
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.new_namespace */
EIF_REFERENCE F270_2593 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,arg2);
	RTLR(1,arg1);
	RTLR(2,Result);
	RTLR(3,Current);
	RTLR(4,tr1);
	RTLIU(5);
	
	RTGC;
	Result = RTLNS(eif_new_type(1183, 0x01).id, 1183, _OBJSIZ_2_0_0_0_0_0_0_0_);
	F1184_11636(RTCW(Result), arg2, arg1);
	tb1 = '\0';
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
	tb2 = F1518_14892(RTCW(tr1), Result);
	if (tb2) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
		tr1 = F1518_14890(RTCW(tr1), Result);
		tb2 = F1184_11643(RTCW(tr1), Result);
		tb1 = tb2;
	}
	if (tb1) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
		tr1 = F1518_14890(RTCW(tr1), Result);
		Result = (EIF_REFERENCE) tr1;
	} else {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
		F1518_14903(RTCW(tr1), Result);
	}
	RTLE;
	return Result;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.handle_position */
void F270_2595 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc2);
	RTLR(4,arg1);
	RTLIU(5);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	loc1 = tr1;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_5_);
	loc2 = tr1;
	if ((EIF_BOOLEAN) (EIF_TEST(loc1) && EIF_TEST(loc2))) {
		tr1 = F2045_22386(loc2);
		F10_129(loc1, tr1, arg1);
	}
	RTLE;
}

void EIF_Minit195 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-25.12.9.8922.tar: F_code/C4/xm195.c <==
/*
 * Code for class XM_CALLBACKS_TO_TREE_FILTER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "xm195.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {XM_CALLBACKS_TO_TREE_FILTER}.initialize */
void F270_2604 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = RTLNSMART(eif_new_type(2019, 1).id);
	F2020_20499(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) NULL;
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,1521,0xFF01,1174,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F1516_15040(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_4_) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.is_position_table_enabled */
EIF_BOOLEAN F270_2606 (EIF_REFERENCE Current)
{
	GTCX
	
	
	return (EIF_BOOLEAN) (EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current + _REFACS_2_) != NULL);
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.enable_position_table */
void F270_2608 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_5_) = (EIF_REFERENCE) arg1;
	tr1 = RTLNSMART(eif_new_type(7, 0).id);
	F8_97(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.on_start */
void F270_2610 (EIF_REFERENCE Current)
{
	GTCX
	
	
	F270_2604(Current);
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.on_start_tag */
void F270_2611 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
	RTLI(9);
	RTLR(0,loc2);
	RTLR(1,arg1);
	RTLR(2,loc3);
	RTLR(3,Current);
	RTLR(4,tr1);
	RTLR(5,loc1);
	RTLR(6,arg3);
	RTLR(7,arg2);
	RTLR(8,tr2);
	RTLIU(9);
	
	RTGC;
	RTCT0("has_resolved_namespaces", EX_CHECK);
	loc2 = arg1;
	if (EIF_TEST(loc2)) {
		RTCK0;
	} else {
		RTCF0;
	}
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	loc3 = tr1;
	if (EIF_TEST(loc3)) {
		loc1 = RTLNS(eif_new_type(2020, 0x01).id, 2020, _OBJSIZ_4_0_0_0_0_0_0_0_);
		tr1 = F270_2618(Current, loc2, arg2);
		F2021_20515(RTCW(loc1), loc3, arg3, tr1);
	} else {
		loc1 = RTLNS(eif_new_type(2020, 0x01).id, 2020, _OBJSIZ_4_0_0_0_0_0_0_0_);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tr2 = F270_2618(Current, loc2, arg2);
		F2021_20516(RTCW(loc1), tr1, arg3, tr2);
	}
	RTAR(Current, loc1);
	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) loc1;
	F270_2620(Current, loc1);
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.on_attribute */
void F270_2612 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3, EIF_REFERENCE arg4)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(9);
	RTLR(0,loc2);
	RTLR(1,arg1);
	RTLR(2,loc3);
	RTLR(3,Current);
	RTLR(4,tr1);
	RTLR(5,loc1);
	RTLR(6,arg3);
	RTLR(7,arg2);
	RTLR(8,arg4);
	RTLIU(9);
	
	RTGC;
	RTCT0("has_resolved_namespaces", EX_CHECK);
	loc2 = arg1;
	if (EIF_TEST(loc2)) {
		RTCK0;
	} else {
		RTCF0;
	}
	RTCT0("element_not_void", EX_CHECK);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	loc3 = tr1;
	if (EIF_TEST(loc3)) {
		RTCK0;
	} else {
		RTCF0;
	}
	loc1 = RTLNS(eif_new_type(2017, 0x01).id, 2017, _OBJSIZ_4_0_0_0_0_0_0_0_);
	tr1 = F270_2618(Current, loc2, arg2);
	F2018_20452(RTCW(loc1), arg3, tr1, arg4, loc3);
	F270_2620(Current, loc1);
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.on_content */
void F270_2613 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc2);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc1);
	RTLR(4,arg1);
	RTLIU(5);
	
	RTGC;
	RTCT0("not_finished", EX_CHECK);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	loc2 = tr1;
	if (EIF_TEST(loc2)) {
		RTCK0;
	} else {
		RTCF0;
	}
	loc1 = RTLNS(eif_new_type(2015, 0x01).id, 2015, _OBJSIZ_2_0_0_0_0_0_0_0_);
	F2016_20435(RTCW(loc1), loc2, arg1);
	F270_2620(Current, loc1);
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.on_end_tag */
void F270_2614 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(4);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc2);
	RTLIU(4);
	
	RTGC;
	RTCT0("open_composite_exists", EX_CHECK);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	loc1 = tr1;
	if (EIF_TEST(loc1)) {
		RTCK0;
	} else {
		RTCF0;
	}
	tb1 = '\01';
	tr1 = *(EIF_REFERENCE *)(loc1);
	loc2 = tr1;
	if (!((EIF_BOOLEAN) !(EIF_TRUE))) {
		tb2 = F2010_20410(loc2);
		tb1 = tb2;
	}
	if (tb1) {
		*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) NULL;
	} else {
		tr1 = F2010_20407(loc1);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) tr1;
	}
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.on_processing_instruction */
void F270_2615 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(6);
	RTLR(0,loc2);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc1);
	RTLR(4,arg1);
	RTLR(5,arg2);
	RTLIU(6);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	loc2 = tr1;
	if (EIF_TEST(loc2)) {
		loc1 = RTLNS(eif_new_type(2014, 0x01).id, 2014, _OBJSIZ_3_0_0_0_0_0_0_0_);
		F2015_20427(RTCW(loc1), loc2, arg1, arg2);
	} else {
		loc1 = RTLNS(eif_new_type(2014, 0x01).id, 2014, _OBJSIZ_3_0_0_0_0_0_0_0_);
		F2015_20428(RTCW(loc1), *(EIF_REFERENCE *)(Current + _REFACS_1_), arg1, arg2);
	}
	F270_2620(Current, loc1);
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.on_comment */
void F270_2616 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc2);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc1);
	RTLR(4,arg1);
	RTLIU(5);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	loc2 = tr1;
	if (EIF_TEST(loc2)) {
		loc1 = RTLNS(eif_new_type(2013, 0x01).id, 2013, _OBJSIZ_2_0_0_0_0_0_0_0_);
		F2014_20421(RTCW(loc1), loc2, arg1);
	} else {
		loc1 = RTLNS(eif_new_type(2013, 0x01).id, 2013, _OBJSIZ_2_0_0_0_0_0_0_0_);
		F2014_20422(RTCW(loc1), *(EIF_REFERENCE *)(Current + _REFACS_1_), arg1);
	}
	F270_2620(Current, loc1);
	RTLE;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.new_namespace */
EIF_REFERENCE F270_2618 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,arg2);
	RTLR(1,arg1);
	RTLR(2,Result);
	RTLR(3,Current);
	RTLR(4,tr1);
	RTLIU(5);
	
	RTGC;
	Result = RTLNS(eif_new_type(1174, 0x01).id, 1174, _OBJSIZ_2_0_0_0_0_0_0_0_);
	F1175_11719(RTCW(Result), arg2, arg1);
	tb1 = '\0';
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
	tb2 = F1516_15045(RTCW(tr1), Result);
	if (tb2) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
		tr1 = F1516_15043(RTCW(tr1), Result);
		tb2 = F1175_11726(RTCW(tr1), Result);
		tb1 = tb2;
	}
	if (tb1) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
		tr1 = F1516_15043(RTCW(tr1), Result);
		Result = (EIF_REFERENCE) tr1;
	} else {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
		F1516_15056(RTCW(tr1), Result);
	}
	RTLE;
	return Result;
}

/* {XM_CALLBACKS_TO_TREE_FILTER}.handle_position */
void F270_2620 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc2);
	RTLR(4,arg1);
	RTLIU(5);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	loc1 = tr1;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_5_);
	loc2 = tr1;
	if ((EIF_BOOLEAN) (EIF_TEST(loc1) && EIF_TEST(loc2))) {
		tr1 = F2081_23471(loc2);
		F8_100(loc1, tr1, arg1);
	}
	RTLE;
}

void EIF_Minit195 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
